==> raga_testing_platform-1.0.53-py3-none-any.whl: raga/constants.py <==
MODEL_REQUIRED_NOT_EMPTY = "model_name is required and must be a non-empty string."
MODEL_VERSION_REQUIRED_NOT_EMPTY = "version is required and must be a non-empty int."
MODEL_LIB_NOT_FOUND = "Model executor lib not found"
INVALID_RESPONSE = "Invalid response data. Expected a dictionary."
INVALID_RESPONSE_MODEL_ID_NOT_FOUND = "Invalid response data. model ID not found."
INVALID_RESPONSE_DATA = "Invalid response data."
INVALID_DATASET = "Invalid dataset."
INVALID_INIT_ARG = "Invalid init_args."
INVALID_EXECUTION_ARG = "Invalid execution_args."
MODEL_OR_PYTHON_NOT_FOUND = "Model platform or python version not found."
WHEEL_NOT_FOUND = "Wheel file not found."
WHEEL_UNINSTALL_FAIL = "Failed to uninstall"
WHEEL_INSTALL_FAIL = "Failed to install"
PLATFORM_NOT_SUPPORT = "The model version does does not support your platform. Please try other model version. Your platform {local_platform}. Model platform version {supported_platforms}."
PYTHON_NOT_SUPPORT = "The python version does does not support your python. Please try other model version. Your version {local_python_version}. Model Python version{supported_python_versions}."

INVALID_SCHEMA = "Invalid schema argument. Expected an instance of RagaSchema."
EMPTY_DATA_FRAME = "Empty DataFrame data argument."
INVALID_DATA_ARG = "Invalid data argument. Expected a DataFrame or a file path or schema."
SCHEMA_KEY_DOES_NOT_EXIST = "Missing required field 'ImageId' in the schema. Please provide 'ImageId' using a PredictionSchemaElement instance."
COL_DOES_NOT_EXIST = "Raga Schema Error: Column name `{col_name}` not found in provided Data Frame. {column_list}"

REQUIRED_ARG = "{0} argument is required."
REQUIRED_ARG_V2 = "{0} is required and must be a/an {1}."
DATASET_FORMAT_ERROR = "Invalid format found in '{0}' column."

==> raga_testing_platform-1.0.55-py3-none-any.whl: raga/constants.py <==
MODEL_REQUIRED_NOT_EMPTY = "model_name is required and must be a non-empty string."
MODEL_VERSION_REQUIRED_NOT_EMPTY = "version is required and must be a non-empty int."
MODEL_LIB_NOT_FOUND = "Model executor lib not found"
INVALID_RESPONSE = "Invalid response data. Expected a dictionary."
INVALID_RESPONSE_MODEL_ID_NOT_FOUND = "Invalid response data. model ID not found."
INVALID_RESPONSE_DATA = "Invalid response data."
INVALID_DATASET = "Invalid dataset."
INVALID_INIT_ARG = "Invalid init_args."
INVALID_EXECUTION_ARG = "Invalid execution_args."
MODEL_OR_PYTHON_NOT_FOUND = "Model platform or python version not found."
WHEEL_NOT_FOUND = "Wheel file not found."
WHEEL_UNINSTALL_FAIL = "Failed to uninstall"
WHEEL_INSTALL_FAIL = "Failed to install"
PLATFORM_NOT_SUPPORT = "The model version does does not support your platform. Please try other model version. Your platform {local_platform}. Model platform version {supported_platforms}."
PYTHON_NOT_SUPPORT = "The python version does does not support your python. Please try other model version. Your version {local_python_version}. Model Python version{supported_python_versions}."

INVALID_SCHEMA = "Invalid schema argument. Expected an instance of RagaSchema."
EMPTY_DATA_FRAME = "Empty DataFrame data argument."
INVALID_DATA_ARG = "Invalid data argument. Expected a DataFrame or a file path or schema."
SCHEMA_KEY_DOES_NOT_EXIST = "Missing required field 'ImageId' in the schema. Please provide 'ImageId' using a PredictionSchemaElement instance."
COL_DOES_NOT_EXIST = "Raga Schema Error: Column name `{0}` not found in provided Data Frame. {1}"

REQUIRED_ARG = "{0} argument is required."
REQUIRED_ARG_V2 = "{0} is required and must be a/an {1}."
DATASET_FORMAT_ERROR = "Invalid format found in '{0}' column."
